@@ -18,7 +18,6 @@ package cmd
 
 import (
 	"github.com/spf13/cobra"
-	"github.com/spf13/pflag"
 
 	"github.com/GoogleContainerTools/skaffold/cmd/skaffold/app/cmd/credits"
 )
@@ -27,8 +26,8 @@ func NewCmdCredits() *cobra.Command {
 	return NewCmd("credits").
 		WithDescription("Export third party notices to given path (./skaffold-credits by default)").
 		WithExample("export third party licenses to ~/skaffold-credits", "credits -d ~/skaffold-credits").
-		WithFlags(func(f *pflag.FlagSet) {
-			f.StringVarP(&credits.Path, "dir", "d", "./skaffold-credits", "destination directory to place third party licenses")
+		WithFlags([]*Flag{
+			{Value: &credits.Path, Name: "dir", Shorthand: "d", DefValue: "./skaffold-credits", Usage: "destination directory to place third party licenses"},
 		}).
 		NoArgs(credits.Export)
 }
