@@ -22,10 +22,6 @@ echo "Running validation scripts..."
 scripts=(
     "hack/check-schema-changes.sh"
     "hack/check-skaffold-builder.sh"
-    "hack/boilerplate.sh"
-    "hack/gofmt.sh"
-    "hack/pedantic-imports.sh"
-    "hack/linter.sh"
     "hack/check-samples.sh"
     "hack/check-docs.sh"
     "hack/test-generated-proto.sh"
