@@ -120,7 +120,7 @@ func TestNetcoreTransformerApply(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			config, image, err := netcoreTransformer{}.Apply(&test.containerSpec, test.configuration, identity)
+			config, image, err := netcoreTransformer{}.Apply(&test.containerSpec, test.configuration, identity, nil)
 
 			t.CheckError(test.shouldErr, err)
 			t.CheckDeepEqual(test.result, test.containerSpec)
