@@ -27,13 +27,13 @@ import (
 	"github.com/segmentio/textio"
 	yamlv3 "gopkg.in/yaml.v3"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	deployerr "github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/error"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/kubectl"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/manifest"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output"
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/warnings"
@@ -41,9 +41,9 @@ import (
 
 var (
 	DefaultKustomizePath = "."
-	kustomizeFilePaths   = []string{"kustomization.yaml", "kustomization.yml", "Kustomization"}
+	KustomizeFilePaths   = []string{"kustomization.yaml", "kustomization.yml", "Kustomization"}
 	basePath             = "base"
-	kustomizeBinaryCheck = kustomizeBinaryExists // For testing
+	KustomizeBinaryCheck = kustomizeBinaryExists // For testing
 )
 
 // kustomization is the content of a kustomization.yaml file.
@@ -112,7 +112,7 @@ func NewDeployer(cfg kubectl.Config, labels map[string]string, d *latestV1.Kusto
 
 	kubectl := kubectl.NewCLI(cfg, d.Flags, defaultNamespace)
 	// if user has kustomize binary, prioritize that over kubectl kustomize
-	useKubectlKustomize := !kustomizeBinaryCheck() && kubectlVersionCheck(kubectl)
+	useKubectlKustomize := !KustomizeBinaryCheck() && kubectlVersionCheck(kubectl)
 
 	return &Deployer{
 		KustomizeDeploy:     d,
@@ -171,8 +171,8 @@ func (k *Deployer) Deploy(ctx context.Context, out io.Writer, builds []graph.Art
 
 func (k *Deployer) renderManifests(ctx context.Context, out io.Writer, builds []graph.Artifact) (manifest.ManifestList, error) {
 	if err := k.kubectl.CheckVersion(ctx); err != nil {
-		color.Default.Fprintln(out, "kubectl client version:", k.kubectl.Version(ctx))
-		color.Default.Fprintln(out, err)
+		output.Default.Fprintln(out, "kubectl client version:", k.kubectl.Version(ctx))
+		output.Default.Fprintln(out, err)
 	}
 
 	debugHelpersRegistry, err := config.GetDebugHelpersRegistry(k.globalConfig)
@@ -306,7 +306,7 @@ func IsKustomizationBase(path string) bool {
 
 func IsKustomizationPath(path string) bool {
 	filename := filepath.Base(path)
-	for _, candidate := range kustomizeFilePaths {
+	for _, candidate := range KustomizeFilePaths {
 		if filename == candidate {
 			return true
 		}
